pub struct FireworkRocketEntity {
base: EntityBase,
entity_type: EntityTypeRef,
entity_data: SyncMutex<FireworkRocketEntityData>,
projectile_base: ProjectileBase,
state: SyncMutex<FireworkRocketState>,
}Expand description
A launched firework rocket.
Fields
base: EntityBaseentity_type: EntityTypeRefentity_data: SyncMutex<FireworkRocketEntityData>projectile_base: ProjectileBasestate: SyncMutex<FireworkRocketState>Implementations
Sourceimpl FireworkRocketEntity
impl FireworkRocketEntity
Sourcepub fn new(
entity_type: EntityTypeRef,
id: i32,
position: DVec3,
world: Weak<World>,
) -> Self
pub fn new( entity_type: EntityTypeRef, id: i32, position: DVec3, world: Weak<World>, ) -> Self
Creates an uninitialized rocket for the entity factory.
Sourcepub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
pub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
Creates a rocket from saved base data.
fn is_base_invulnerable_to(&self, source: &DamageSource) -> bool
Sourcepub fn launched(
entity_type: EntityTypeRef,
id: i32,
position: DVec3,
world: Weak<World>,
source_item: ItemStack,
) -> Self
pub fn launched( entity_type: EntityTypeRef, id: i32, position: DVec3, world: Weak<World>, source_item: ItemStack, ) -> Self
Creates a normally launched rocket at an exact position.
Sourcepub fn attached_to_living(
entity_type: EntityTypeRef,
id: i32,
world: Weak<World>,
source_item: ItemStack,
attached_to: &dyn LivingEntity,
) -> Self
pub fn attached_to_living( entity_type: EntityTypeRef, id: i32, world: Weak<World>, source_item: ItemStack, attached_to: &dyn LivingEntity, ) -> Self
Creates a rocket attached to a living entity that will be resolved from its synced runtime ID after the rocket enters the world.
fn initialize_launch(&self, source_item: ItemStack)
Sourcepub fn set_shot_at_angle(&self, shot_at_angle: bool)
pub fn set_shot_at_angle(&self, shot_at_angle: bool)
Sets whether this rocket was fired at an angle.
Sourcepub fn is_shot_at_angle(&self) -> bool
pub fn is_shot_at_angle(&self) -> bool
Returns whether this rocket was fired at an angle.
fn is_attached_to_entity(&self) -> bool
fn attached_entity(&self, world: &Arc<World>) -> Option<SharedEntity>
fn tick_attached(&self, world: &Arc<World>) -> Option<ProjectileHit>
fn tick_free_flying(&self) -> Option<ProjectileHit>
fn explosion_count(&self) -> usize
fn has_explosion(&self) -> bool
fn fireworks_damage_source(&self) -> DamageSource
fn deal_explosion_damage(&self, world: &Arc<World>)
fn explode(&self, world: &Arc<World>)
fn run_hit_block_entity_inside(&self, world: &Arc<World>, hit: &ClipHitResult)